==> 0.5.0.tar.gz: wechat_mall_applet/pages/index/index.js <==
const product = require('../../utils/product.js')

Page({
  data: {
    items: [],
    slides: [],
    navs: [{icon: "../../images/asset.png",       name: "资产"},
           {icon: "../../images/direct_sale.png", name: "直销"},
           {icon: "../../images/our_select.png",  name: "甄选"},
           {icon: "../../images/packing.png",     name: "包装"}],

    popularity_products: [],
    new_products: [],
    hot_products: [],
    promotions: []
  },

  bindShowProduct: function (e) {
    wx.navigateTo({
      url: `../show_product/show_product?id=${e.currentTarget.dataset.id}`
    })
  },

  catchTapCategory: function (e) {
    wx.navigateTo({
      url: `../category/category?type=${e.currentTarget.dataset.type}`
    })
  },

  onLoad: function() {
    var that = this

    product.getSlides(function(result) {
      var data = getApp().store.sync(result.data)
      that.setData({'slides': data})
      wx.setStorage({
        key:"indexSlides",
        data:data
      })
    })

    product.getProducts(function(result) {
      var data = getApp().store.sync(result.data)
      that.setData({
        items: data,
        popularity_products: data.filter(product => product.flag === '最热'),
        new_products:        data.filter(product => product.flag === '新品'),
        hot_products:        data.filter(product => product.flag === '火爆'),
      })
      wx.setStorageSync('products', data)
    })

    // wx.getNetworkType({
    //   success: function(res) {
    //     var networkType = res.networkType // 返回网络类型2g，3g，4g，wifi
    //     if (networkType) {
    //     } else {
    //        cache = wx.getStorageSync('products')
    //        if (cache) {
    //          that.setData({'items': cache})
    //        } else {
    //          that.setData({'items': []})
    //        }
    //     }
    //   }
    // })
  }
})

==> 1.2.2.tar.gz: wechat_mall_applet/pages/index/index.js <==
const product = require('../../utils/product.js')
var app = getApp()

Page({
  data: {
    items: [],
    slides: [],
    navs: [{icon: "../../images/icon-new-list1.png", name: "资产"},
           {icon: "../../images/icon-new-list2.png", name: "直销"},
           {icon: "../../images/icon-new-list3.png", name: "甄选"},
           {icon: "../../images/icon-new-list4.png", name: "管到"}],

    popularity_products: [],
    new_products: [],
    hot_products: [],
    promotions: []
  },

  bindShowProduct: function (e) {
    wx.navigateTo({
      url: `../show_product/show_product?id=${e.currentTarget.dataset.id}`
    })
  },

  catchTapCategory: function (e) {
    wx.navigateTo({
      url: `../category/category?type=${e.currentTarget.dataset.type}`
    })
  },

  onLoad: function() {
    var that = this

    product.getSlides(function(result) {
      var data = app.store.sync(result.data)
      that.setData({'slides': data})
      wx.setStorage({
        key:"indexSlides",
        data:data
      })
    })

    product.getProducts(function(result) {
      var data = app.store.sync(result.data)
      that.setData({
        items: data,
        popularity_products: data.filter(product => (product.flag === '最热' && product['promotion-url'])),
        new_products:        data.filter(product => (product.flag === '新品' && product['promotion-url'])),
        hot_products:        data.filter(product => (product.flag === '火爆' && product['promotion-url'])),
      })
      wx.setStorageSync('products', data)
    })

    // wx.getNetworkType({
    //   success: function(res) {
    //     var networkType = res.networkType // 返回网络类型2g，3g，4g，wifi
    //     if (networkType) {
    //     } else {
    //        cache = wx.getStorageSync('products')
    //        if (cache) {
    //          that.setData({'items': cache})
    //        } else {
    //          that.setData({'items': []})
    //        }
    //     }
    //   }
    // })
  }
})
